@@ -395,6 +395,7 @@ public:
                                          bool noWait = false);
 #endif
 
+#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 83)
     /**
      * Starts a program via kdeinit.
      *
@@ -411,12 +412,15 @@ public:
      * @param startup_id for app startup notification, "0" for none,
      *           "" ( empty string ) is the default
      * @return an error code indicating success (== 0) or failure (> 0).
+     * @deprecated since 5.83, use CommandLauncherJob instead
      */
+    KSERVICE_DEPRECATED_VERSION(5, 83, "use CommandLauncherJob instead")
     static int kdeinitExec(const QString &name,
                            const QStringList &args = QStringList(),
                            QString *error = nullptr,
                            int *pid = nullptr,
                            const QByteArray &startup_id = QByteArray());
+#endif
 
     /**
      * Starts a program via kdeinit and wait for it to finish.
